==> lire_1.5.orig.tar.gz: lire-1.5/dns/po/lire-dns.pot.pl <==
# REFERENCE: dns.cfg
__( q{All Requests} );
# REFERENCE: dns.cfg
__( q{Recursive Requests} );
# REFERENCE: dns.cfg
__( q{Non Recursive Requests} );
# REFERENCE: schema:dns
__( q{DLF Schema for DNS service} );
# REFERENCE: schema:dns
__( q{Each records in the DNS DLF schema represents a query that was
   made to the DNS server, zone transfers or other types of
   administrative information isn't represented in the schema.
  } );
# REFERENCE: schema:dns
__( q{Timestamp} );
# REFERENCE: schema:dns
__( q{The time at which the query was processed by the server.} );
# REFERENCE: schema:dns
__( q{Client Host} );
# REFERENCE: schema:dns
__( q{The host that made the request.} );
# REFERENCE: schema:dns
__( q{Requested Name} );
# REFERENCE: schema:dns
__( q{The content of the DNS request. DNS queries are usually about
    an hostname. 
   } );
# REFERENCE: schema:dns
__( q{Request's Type} );
# REFERENCE: schema:dns
__( q{The record type that was requested. Common DNS record types
    are <type>PTR</type>, <type>A</type>, <type>CNAME</type>, etc.
   } );
# REFERENCE: schema:dns
__( q{Recursive Request} );
# REFERENCE: schema:dns
__( q{This field contains <constant>recurs</constant> if the
    requests was recursive, that is probably made by a client for
    which we are configured as primary DNS server. Otherwise this
    field contains <constant>norecurs</constant> to denotes that the
    request wasn't recursive. Non-recursive requests are usually made
    by a DNS server which is processing a recursive request from one
    client.
   } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests by Period by Method DNS Report} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{This report shows the number of requests aggregated in
   configurable time periods and splitted by the resolver's
   type.
  } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{This parameter controls the time period over which the
     requests are aggregated.
    } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests by $period by Method} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Period} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{% Total} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{% Group} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests by Timeslot by Method DNS Report} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{This report shows the number of requests aggregated in
   configurable time slots (by hours of the day, by days of the weeks,
   etc.) and splitted by the resolver's type.
  } );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{This parameter controls the time slot over which the
     requests are aggregated.
    } );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests by $timeslot Timeslot by Method} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{% Total} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{% Group} );
# REFERENCE: report:dns:requests-by-period
__( q{Requests By Period DNS Report} );
# REFERENCE: report:dns:requests-by-period
__( q{This report shows the number of requests aggregated in
    configurable time periods.} );
# REFERENCE: report:dns:requests-by-period
__( q{This parameter controls the time period over which the
     requests are aggregated.
    } );
# REFERENCE: report:dns:requests-by-period
__( q{Requests By $period} );
# REFERENCE: report:dns:requests-by-period
__( q{Period} );
# REFERENCE: report:dns:requests-by-period
__( q{Requests} );
# REFERENCE: report:dns:requests-by-period
__( q{% Total} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests By Timeslot DNS Report} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{This report shows the number of requests aggregated in
   configurable time slots (by hours of the day, by days of the weeks,
   etc.).} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{This parameter controls the time slot over which the
     requests are aggregated.
    } );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests by $timeslot Timeslot} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Timeslot} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{% Total} );
# REFERENCE: report:dns:requesttype-by-method
__( q{Distribution of Request Types by Method DNS Report} );
# REFERENCE: report:dns:requesttype-by-method
__( q{This report shows the distribution of the type of requests
   splitted by method.
  } );
# REFERENCE: report:dns:requesttype-by-method
__( q{Distribution of Request Types by Method} );
# REFERENCE: report:dns:requesttype-by-method
__( q{Requests} );
# REFERENCE: report:dns:requesttype-by-method
__( q{% Total} );
# REFERENCE: report:dns:requesttype-by-method
__( q{% Group} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Distribution of Request Types Report} );
# REFERENCE: report:dns:requesttype-distribution
__( q{This reports on the distribution of the request types.} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Distribution of Request Types} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Requests} );
# REFERENCE: report:dns:requesttype-distribution
__( q{% Total} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Top Requesting Hosts Report} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This report lists the requesting hosts with the most requests
   and it displays more detailed information on those requests: it
   shows the breakdown of requested names and request types.
  } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This parameter controls the number of requested names to
     display by host in the report.
    } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Number of Lookups by Hosts, Top $hosts_to_show (Detailed Report)} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Requests} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Requests} );
# REFERENCE: report:dns:top-requested-names
__( q{Top Requested Names Report} );
# REFERENCE: report:dns:top-requested-names
__( q{This report lists the most requested names.} );
# REFERENCE: report:dns:top-requested-names
__( q{This parameter controls the number of names to
     display in the report.
    } );
# REFERENCE: report:dns:top-requested-names
__( q{Number of Lookups by Names, Top $names_to_show} );
# REFERENCE: report:dns:top-requested-names
__( q{Requests} );
# REFERENCE: report:dns:top-requested-names
__( q{% Total} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Top Requesting Hosts Report} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{This parameter controls the number of hosts to
     display in the report.
    } );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Number of Lookups by Hosts, Top $hosts_to_show} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Requests} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{% Total} );
# REFERENCE: filter:dns:select-resolver
__( q{Select Resolver Filter} );
# REFERENCE: filter:dns:select-resolver
__( q{This filter specification can be used to select only DLF
   records having a particular resolver type.
  } );
# REFERENCE: filter:dns:select-resolver
__( q{This parameter sets the type of resolver that should be
     selected.
     Possible methods are:
     <variablelist>
      <varlistentry>
       <term>nonrec</term>
       <listitem>
        <para>Non-recursive requests.</para>
       </listitem>
      </varlistentry>
      <varlistentry>
       <term>recurs</term>
       <listitem>
        <para>Recursive requests.</para>
       </listitem>
      </varlistentry>
     </variablelist>
    } );
# REFERENCE: filter:dns:select-resolver
__( q{$method requests} );

==> lire_2.1.1.orig.tar.gz: lire-2.1.1/dns/po/lire-dns.pot.pl <==
# REFERENCE: dns_default.xml
__( q{All Requests} );
# REFERENCE: dns_default.xml
__( q{Recursive Requests} );
# REFERENCE: dns_default.xml
__( q{Non Recursive Requests} );
# REFERENCE: schema:dns
__( q{DLF Schema for DNS service} );
# REFERENCE: schema:dns
__( q{Each records in the DNS DLF schema represents a query that was made to the DNS server, zone transfers or other types of administrative information isn't represented in the schema. } );
# REFERENCE: schema:dns
__( q{Timestamp} );
# REFERENCE: schema:dns
__( q{The time at which the query was processed by the server.} );
# REFERENCE: schema:dns
__( q{Client Host} );
# REFERENCE: schema:dns
__( q{The host that made the request.} );
# REFERENCE: schema:dns
__( q{Requested Name} );
# REFERENCE: schema:dns
__( q{The content of the DNS request. DNS queries are usually about an hostname. } );
# REFERENCE: schema:dns
__( q{Request's Type} );
# REFERENCE: schema:dns
__( q{The record type that was requested. Common DNS record types are <type>PTR</type>, <type>A</type>, <type>CNAME</type>, etc. } );
# REFERENCE: schema:dns
__( q{Recursive Request} );
# REFERENCE: schema:dns
__( q{This field contains <constant>recurs</constant> if the requests was recursive, that is probably made by a client for which we are configured as primary DNS server. Otherwise this field contains <constant>norecurs</constant> to denotes that the request wasn't recursive. Non-recursive requests are usually made by a DNS server which is processing a recursive request from one client. } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests by Period by Method DNS Report} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{This report shows the number of requests aggregated in configurable time periods and splitted by the resolver's type. } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{This parameter controls the time period over which the requests are aggregated. } );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests by $period by Method} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Period} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{Requests} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{% Total} );
# REFERENCE: report:dns:req-by-period-by-method
__( q{% Group} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests by Timeslot by Method DNS Report} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{This report shows the number of requests aggregated in configurable time slots (by hours of the day, by days of the weeks, etc.) and splitted by the resolver's type. } );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{This parameter controls the time slot over which the requests are aggregated. } );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests by $timeslot Timeslot by Method} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{Requests} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{% Total} );
# REFERENCE: report:dns:req-by-timeslot-by-method
__( q{% Group} );
# REFERENCE: report:dns:requests-by-period
__( q{Requests By Period DNS Report} );
# REFERENCE: report:dns:requests-by-period
__( q{This report shows the number of requests aggregated in configurable time periods.} );
# REFERENCE: report:dns:requests-by-period
__( q{This parameter controls the time period over which the requests are aggregated. } );
# REFERENCE: report:dns:requests-by-period
__( q{Requests By $period} );
# REFERENCE: report:dns:requests-by-period
__( q{Period} );
# REFERENCE: report:dns:requests-by-period
__( q{Requests} );
# REFERENCE: report:dns:requests-by-period
__( q{% Total} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests By Timeslot DNS Report} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{This report shows the number of requests aggregated in configurable time slots (by hours of the day, by days of the weeks, etc.).} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{This parameter controls the time slot over which the requests are aggregated. } );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests by $timeslot Timeslot} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Timeslot} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{Requests} );
# REFERENCE: report:dns:requests-by-timeslot
__( q{% Total} );
# REFERENCE: report:dns:requesttype-by-method
__( q{Distribution of Request Types by Method DNS Report} );
# REFERENCE: report:dns:requesttype-by-method
__( q{This report shows the distribution of the type of requests splitted by method. } );
# REFERENCE: report:dns:requesttype-by-method
__( q{Distribution of Request Types by Method} );
# REFERENCE: report:dns:requesttype-by-method
__( q{Requests} );
# REFERENCE: report:dns:requesttype-by-method
__( q{% Total} );
# REFERENCE: report:dns:requesttype-by-method
__( q{% Group} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Distribution of Request Types Report} );
# REFERENCE: report:dns:requesttype-distribution
__( q{This reports on the distribution of the request types.} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Distribution of Request Types} );
# REFERENCE: report:dns:requesttype-distribution
__( q{Requests} );
# REFERENCE: report:dns:requesttype-distribution
__( q{% Total} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Top Requesting Hosts Report} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This report lists the requesting hosts with the most requests and it displays more detailed information on those requests: it shows the breakdown of requested names and request types. } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{This parameter controls the number of requested names to display by host in the report. } );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Number of Lookups by Hosts, Top $hosts_to_show (Detailed Report)} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Requests} );
# REFERENCE: report:dns:top-clients-detailed-report
__( q{Requests} );
# REFERENCE: report:dns:top-requested-names
__( q{Top Requested Names Report} );
# REFERENCE: report:dns:top-requested-names
__( q{This report lists the most requested names.} );
# REFERENCE: report:dns:top-requested-names
__( q{This parameter controls the number of names to display in the report. } );
# REFERENCE: report:dns:top-requested-names
__( q{Number of Lookups by Names, Top $names_to_show} );
# REFERENCE: report:dns:top-requested-names
__( q{Requests} );
# REFERENCE: report:dns:top-requested-names
__( q{% Total} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Top Requesting Hosts Report} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{This report lists the requesting hosts with the most requests.} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{This parameter controls the number of hosts to display in the report. } );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Number of Lookups by Hosts, Top $hosts_to_show} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{Requests} );
# REFERENCE: report:dns:top-requesting-hosts
__( q{% Total} );
# REFERENCE: filter:dns:select-resolver
__( q{Select Resolver Filter} );
# REFERENCE: filter:dns:select-resolver
__( q{This filter specification can be used to select only DLF records having a particular resolver type. } );
# REFERENCE: filter:dns:select-resolver
__( q{This parameter sets the type of resolver that should be selected. Possible methods are: <variablelist> <varlistentry> <term>nonrec</term> <listitem> <para>Non-recursive requests.</para> </listitem> </varlistentry> <varlistentry> <term>recurs</term> <listitem> <para>Recursive requests.</para> </listitem> </varlistentry> </variablelist> } );
# REFERENCE: filter:dns:select-resolver
__( q{$method requests} );
